#[non_exhaustive]pub enum CoreError {
Unsupported,
PermissionDenied,
Platform(String),
}Expand description
Cross-cutting error variants shared by waterkit capability crates.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
Operation is not supported on the current platform / OS / device.
PermissionDenied
User has not granted the required permission, or the OS denies it at policy level (e.g. parental controls, MDM).
Platform(String)
Platform-level failure with a message from the underlying API.